@@ -13,6 +13,9 @@ class RuleSet(dict):
             raise KeyError('A rule with name `%s` already exists' % name)
         self[name] = pred
 
+    def set_rule(self, name, pred):
+        self[name] = pred
+
     def remove_rule(self, name):
         del self[name]
 
@@ -30,6 +33,10 @@ def add_rule(name, pred):
     default_rules.add_rule(name, pred)
 
 
+def set_rule(name, pred):
+    default_rules.set_rule(name, pred)
+
+
 def remove_rule(name):
     default_rules.remove_rule(name)
 
